@@ -1,3 +1,5 @@
+import pdb
+
 import pandas as pd
 import rasterio
 from rasterio.control import GroundControlPoint
@@ -13,16 +15,17 @@ from .base_meta import BaseMeta
 
 class RadarSat2Meta(BaseMeta):
     """
-        Handle dataset metadata.
-        A `xsar.RadarSat2Meta` object can be used with `xsar.open_dataset`,
-        but it can be used as itself: it contains usefull attributes and methods.
+    Handle dataset metadata.
+    A `xsar.RadarSat2Meta` object can be used with `xsar.open_dataset`,
+    but it can be used as itself: it contains usefull attributes and methods.
 
-        Parameters
-        ----------
-        name: str
-            path or gdal identifier
+    Parameters
+    ----------
+    name: str
+        path or gdal identifier
 
     """
+
     # class attributes are needed to fetch instance attribute (ie self.name) with dask actors
     # ref http://distributed.dask.org/en/stable/actors.html#access-attributes
     # FIXME: not needed if @property, so it might be a good thing to have getter for those attributes
@@ -33,30 +36,31 @@ class RadarSat2Meta(BaseMeta):
         super().__init__()
 
         from xradarsat2 import rs2_reader
-        if ':' in name:
-            self.dt = rs2_reader(name.split(':')[1])
+
+        if ":" in name:
+            self.dt = rs2_reader(name.split(":")[1])
         else:
             self.dt = rs2_reader(name)
-        if not name.startswith('RADARSAT2_DS:'):
-            name = 'RADARSAT2_DS:%s:' % name
+        if not name.startswith("RADARSAT2_DS:"):
+            name = "RADARSAT2_DS:%s:" % name
         self.name = name
         """Gdal dataset name"""
-        name_parts = self.name.split(':')
+        name_parts = self.name.split(":")
         if len(name_parts) > 3:
             # windows might have semicolon in path ('c:\...')
-            name_parts[1] = ':'.join(name_parts[1:-1])
+            name_parts[1] = ":".join(name_parts[1:-1])
             del name_parts[2:-1]
         name_parts[1] = os.path.basename(name_parts[1])
-        self.short_name = ':'.join(name_parts)
+        self.short_name = ":".join(name_parts)
         """Like name, but without path"""
-        self.path = ':'.join(self.name.split(':')[1:-1])
+        self.path = ":".join(self.name.split(":")[1:-1])
         """Dataset path"""
         self.safe = os.path.basename(self.path)
         """Safe file name"""
         # there is no information on resolution 'F' 'H' or 'M' in the manifest, so we have to extract it from filename
         try:
-            self.product = os.path.basename(self.path).split('_')[9]
-        except:
+            self.product = os.path.basename(self.path).split("_")[9]
+        except ValueError:
             self.product = "XXX"
         """Product type, like 'GRDH', 'SLC', etc .."""
 
@@ -71,44 +75,50 @@ class RadarSat2Meta(BaseMeta):
         """True if multi dataset"""
         self.subdatasets = gpd.GeoDataFrame(geometry=[], index=[])
         """Subdatasets as GeodataFrame (empty if single dataset)"""
-        self.geoloc = self.dt['geolocationGrid'].to_dataset()
+        self.geoloc = self.dt["geolocationGrid"].to_dataset()
 
-        self.orbit_and_attitude = self.dt['orbitAndAttitude'].ds
-        self.doppler_centroid = self.dt['imageGenerationParameters']['doppler']['dopplerCentroid'].ds
-        self.doppler_rate_values = self.dt['imageGenerationParameters']['doppler']['dopplerRateValues'].ds
-        self.chirp = self.dt['imageGenerationParameters']['chirp'].ds
-        self.radar_parameters = self.dt['radarParameters'].ds
-        self.lut = self.dt['lut'].ds
+        self.orbit_and_attitude = self.dt["orbitAndAttitude"].ds
+        self.doppler_centroid = self.dt["imageGenerationParameters"]["doppler"][
+            "dopplerCentroid"
+        ].ds
+        self.doppler_rate_values = self.dt["imageGenerationParameters"]["doppler"][
+            "dopplerRateValues"
+        ].ds
+        self.chirp = self.dt["imageGenerationParameters"]["chirp"].ds
+        self.radar_parameters = self.dt["radarParameters"].ds
+        self.lut = self.dt["lut"].ds
         self.manifest_attrs = self._create_manifest_attrs()
         for name, feature in self.__class__._mask_features_raw.items():
             self.set_mask_feature(name, feature)
 
     def _create_manifest_attrs(self):
         dic = dict()
-        dic["swath_type"] = os.path.basename(self.path).split('_')[4]
+        dic["swath_type"] = os.path.basename(self.path).split("_")[4]
         dic["polarizations"] = self.dt["radarParameters"]["pole"].values
         dic["product_type"] = self.product
-        dic['satellite'] = self.dt.attrs['satellite']
-        dic['start_date'] = self.start_date
-        dic['stop_date'] = self.stop_date
+        dic["satellite"] = self.dt.attrs["satellite"]
+        dic["start_date"] = self.start_date
+        dic["stop_date"] = self.stop_date
         # compute attributes (footprint, coverage, pixel_size)
         footprint_dict = {}
-        for ll in ['longitude', 'latitude']:
+        for ll in ["longitude", "latitude"]:
             footprint_dict[ll] = [
-                self.geoloc[ll].isel(line=a, pixel=x).values for a, x in [(0, 0), (0, -1), (-1, -1), (-1, 0)]
+                self.geoloc[ll].isel(line=a, pixel=x).values
+                for a, x in [(0, 0), (0, -1), (-1, -1), (-1, 0)]
             ]
-        corners = list(
-            zip(footprint_dict['longitude'], footprint_dict['latitude']))
+        corners = list(zip(footprint_dict["longitude"], footprint_dict["latitude"]))
         p = Polygon(corners)
-        self.geoloc.attrs['footprint'] = p
+        self.geoloc.attrs["footprint"] = p
         dic["footprints"] = p
         # compute acquisition size/resolution in meters
         # first vector is on sample
         acq_sample_meters, _ = haversine(*corners[0], *corners[1])
         # second vector is on line
         acq_line_meters, _ = haversine(*corners[1], *corners[2])
-        dic['coverage'] = "%dkm * %dkm (line * sample )" % (
-            acq_line_meters / 1000, acq_sample_meters / 1000)
+        dic["coverage"] = "%dkm * %dkm (line * sample )" % (
+            acq_line_meters / 1000,
+            acq_sample_meters / 1000,
+        )
 
         def _to_rio_gcp(pt_geoloc):
             # convert a point from self._geoloc grid to rasterio GroundControlPoint
@@ -117,15 +127,16 @@ class RadarSat2Meta(BaseMeta):
                 y=pt_geoloc.latitude.item(),
                 z=pt_geoloc.height.item(),
                 col=pt_geoloc.line.item(),
-                row=pt_geoloc.pixel.item()
+                row=pt_geoloc.pixel.item(),
             )
 
         gcps = [
             _to_rio_gcp(self.geoloc.sel(line=line, pixel=sample))
-            for line in self.geoloc.line for sample in self.geoloc.pixel
+            for line in self.geoloc.line
+            for sample in self.geoloc.pixel
         ]
         # approx transform, from all gcps (inaccurate)
-        dic['approx_transform'] = rasterio.transform.from_gcps(gcps)
+        dic["approx_transform"] = rasterio.transform.from_gcps(gcps)
         return dic
 
     @property
@@ -155,24 +166,30 @@ class RadarSat2Meta(BaseMeta):
         xsar.BaseMeta.ll2coords
 
         """
-        return self.manifest_attrs['approx_transform']
+        return self.manifest_attrs["approx_transform"]
 
-    def to_dict(self, keys='minimal'):
+    def to_dict(self, keys="minimal"):
 
         info_keys = {
-            'minimal': [
+            "minimal": [
                 # 'platform',
-                'swath', 'product', 'pols']
+                "swath",
+                "product",
+                "pols",
+            ]
         }
-        info_keys['all'] = info_keys['minimal'] + ['name', 'start_date', 'stop_date',
-                                                   'footprint',
-                                                   'coverage',
-                                                   'pixel_line_m', 'pixel_sample_m',
-                                                   'approx_transform',
-
-                                                   # 'orbit_pass',
-                                                   # 'platform_heading'
-                                                   ]
+        info_keys["all"] = info_keys["minimal"] + [
+            "name",
+            "start_date",
+            "stop_date",
+            "footprint",
+            "coverage",
+            "pixel_line_m",
+            "pixel_sample_m",
+            "approx_transform",
+            # 'orbit_pass',
+            # 'platform_heading'
+        ]
 
         if isinstance(keys, str):
             keys = info_keys[keys]
@@ -184,19 +201,18 @@ class RadarSat2Meta(BaseMeta):
             elif k in self.manifest_attrs.keys():
                 res_dict[k] = self.manifest_attrs[k]
             else:
-                raise KeyError(
-                    'Unable to find key/attr "%s" in RadarSat2Meta' % k)
+                raise KeyError('Unable to find key/attr "%s" in RadarSat2Meta' % k)
         return res_dict
 
     @property
     def pols(self):
-        """polarisations strings, separated by spaces """
-        return " ".join(self.manifest_attrs['polarizations'])
+        """polarisations strings, separated by spaces"""
+        return " ".join(self.manifest_attrs["polarizations"])
 
     @property
     def footprint(self):
         """footprint, as a shapely polygon or multi polygon"""
-        return self.geoloc.attrs['footprint']
+        return self.geoloc.attrs["footprint"]
 
     @property
     def pixel_line_m(self):
@@ -204,7 +220,7 @@ class RadarSat2Meta(BaseMeta):
         if self.multidataset:
             res = None  # not defined for multidataset
         else:
-            res = self.geoloc.line.attrs['rasterAttributes_sampledLineSpacing_value']
+            res = self.geoloc.line.attrs["rasterAttributes_sampledLineSpacing_value"]
         return res
 
     @property
@@ -213,16 +229,22 @@ class RadarSat2Meta(BaseMeta):
         if self.multidataset:
             res = None  # not defined for multidataset
         else:
-            res = self.geoloc.pixel.attrs['rasterAttributes_sampledPixelSpacing_value']
+            res = self.geoloc.pixel.attrs["rasterAttributes_sampledPixelSpacing_value"]
         return res
 
     def _get_time_range(self):
         if self.multidataset:
-            time_range = [self.manifest_attrs['start_date'],
-                          self.manifest_attrs['stop_date']]
+            time_range = [
+                self.manifest_attrs["start_date"],
+                self.manifest_attrs["stop_date"],
+            ]
         else:
             time_range = self.orbit_and_attitude.timeStamp
-        return pd.Interval(left=pd.Timestamp(time_range.values[0]), right=pd.Timestamp(time_range.values[-1]), closed='both')
+        return pd.Interval(
+            left=pd.Timestamp(time_range.values[0]),
+            right=pd.Timestamp(time_range.values[-1]),
+            closed="both",
+        )
 
     @property
     def get_azitime(self):
@@ -264,7 +286,7 @@ class RadarSat2Meta(BaseMeta):
         ---------
             get longitude at line=100 and sample=200:
             ```
-            >>> self._dict_coords2ll['longitude'].ev(100,200)
+            >>> self._dict_coords2ll["longitude"].ev(100, 200)
             array(-66.43947434)
             ```
         Notes:
@@ -274,14 +296,15 @@ class RadarSat2Meta(BaseMeta):
         resdict = {}
         geoloc = self.geoloc
         if self.cross_antemeridian:
-            geoloc['longitude'] = geoloc['longitude'] % 360
+            geoloc["longitude"] = geoloc["longitude"] % 360
 
         idx_sample = np.array(geoloc.pixel)
         idx_line = np.array(geoloc.line)
 
-        for ll in ['longitude', 'latitude']:
+        for ll in ["longitude", "latitude"]:
             resdict[ll] = RectBivariateSpline(
-                idx_line, idx_sample, np.asarray(geoloc[ll]), kx=1, ky=1)
+                idx_line, idx_sample, np.asarray(geoloc[ll]), kx=1, ky=1
+            )
 
         return resdict
 
@@ -290,17 +313,21 @@ class RadarSat2Meta(BaseMeta):
         When a product is flipped, flip back data arrays (from the reader datatree) sample dimensions to respect the xsar
         convention (increasing incidence values)
         """
-        antenna_pointing = self.dt['radarParameters'].attrs['antennaPointing']
-        pass_direction = self.dt.attrs['passDirection']
-        flipped_cases = [('Left', 'Ascending'), ('Right', 'Descending')]
-        samples_depending_ds = ['geolocationGrid', 'lut', 'radarParameters']
+        antenna_pointing = self.dt["radarParameters"].attrs["antennaPointing"]
+        pass_direction = self.dt.attrs["passDirection"]
+        flipped_cases = [("Left", "Ascending"), ("Right", "Descending")]
+        samples_depending_ds = ["geolocationGrid", "lut", "radarParameters"]
         if (antenna_pointing, pass_direction) in flipped_cases:
             for ds_name in samples_depending_ds:
-                if 'radar' in ds_name:
-                    self.dt[ds_name] = self.dt[ds_name].rename(
-                        {'NbOfNoiseLevelValues': 'pixel'})
-                self.dt[ds_name] = self.dt[ds_name].copy().isel(pixel=slice(None, None, -1))\
-                    .assign_coords(pixel=self.dt[ds_name].ds.pixel)
+                ds = self.dt[ds_name].ds
+                if "radar" in ds_name:
+                    ds = ds.rename({"NbOfNoiseLevelValues": "pixel"})
+                ds = (
+                    ds.copy()
+                    .isel(pixel=slice(None, None, -1))
+                    .assign_coords(pixel=ds.pixel)
+                )
+                self.dt[ds_name] = ds
             self.samples_flipped = True
         return
 
@@ -312,11 +339,16 @@ class RadarSat2Meta(BaseMeta):
         system where the range increases to the right and the zero-Doppler time increases downward. Note that this is
         not necessarily the top-left pixel of the image block in the final product.`
         """
-        pass_direction = self.dt.attrs['passDirection']
-        samples_depending_ds = ['geolocationGrid']
-        if pass_direction == 'Ascending':
+        pass_direction = self.dt.attrs["passDirection"]
+        samples_depending_ds = ["geolocationGrid"]
+        if pass_direction == "Ascending":
             for ds_name in samples_depending_ds:
-                self.dt[ds_name] = self.dt[ds_name].copy().isel(line=slice(None, None, -1))\
-                    .assign_coords(line=self.dt[ds_name].ds.line)
+                ds = self.dt[ds_name].ds
+                ds = (
+                    ds.copy()
+                    .isel(line=slice(None, None, -1))
+                    .assign_coords(line=ds.line)
+                )
+                self.dt[ds_name] = ds
             self.lines_flipped = True
         return
